---
name: Add model
about: Add a new model in unified format
title: "[Model] "
labels: model, new
assignees: ''

---

- **Name:** *name of the model*
- **Description:** *short description of the model (or link to social media or blog post)*
- **Paper:** *link to the model paper if available*
- **Repo:** *link to the Github repository of official implementation*
- **License:** *what is the license of the code*
- **Motivation:** *what are some good reasons to have this model*


### Checkbox

- [ ] The model supports unified data format and provides training scripts.
- [ ] The model has implemented module interface and can be used to build an agent (Add examples in `agent_examples`).
- [ ] Add the model card `README` under its directory.
- [ ] Upload the checkpoints, and model card to https://huggingface.co/ConvLab
- [ ] Update `NOTICE` with license information.
